==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/it-IT/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Informazioni sugli asset',
    'about_assets_text'            => 'Gli asset sono elementi tracciati con il numero di serie o il tag di asset. Tendono ad essere oggetti di valore più elevato dove identificare un elemento specifico.',
    'archived'  				=> 'Archiviato',
    'asset'  					=> 'Asset',
    'bulk_checkout'             => 'Ritiro Asset',
    'bulk_checkin'              => 'Check-in Bene',
    'checkin'  					=> 'Ingresso Asset',
    'checkout'  				=> 'Asset Checkout',
    'clone'  					=> 'Copia Asset',
    'deployable'  				=> 'Assegnabile',
    'deleted'  					=> 'Questo bene è stato eliminato.',
    'delete_confirm'            => 'Sei sicuro di voler eliminare questo bene?',
    'edit'  					=> 'Modifica Asset',
    'model_deleted'  			=> 'Questo modello di asset è stato eliminato. Devi ripristinare il modello prima di poter ripristinare il bene.',
    'model_invalid'             => 'Il modello di questo bene non è valido.',
    'model_invalid_fix'         => 'Il bene deve avere un modello valido prima di poterne fare l\'assegnazioni, check-in o controlli.',
    'requestable'               => 'Disponibile',
    'requested'				    => 'richiesto',
    'not_requestable'           => 'Non Richiedibili',
    'requestable_status_warning' => 'Non cambiare richiedibilità',
    'restore'  					=> 'Ripristina Asset',
    'pending'  					=> 'In attesa',
    'undeployable'  			=> 'Non Distribuilbile',
    'undeployable_tooltip'  	=> 'Questo bene ha una etichetta che lo rende non distribuibile, il check-out non può avvenire.',
    'view'  					=> 'Vedi Asset',
    'csv_error' => 'C\'è un errore nel file CSV:',
    'import_text' => '<p>Carica un CSV che contiene la cronologia degli asset. Gli asset e gli utenti DEVONO già esistere nel sistema, o saranno saltati. Le risorse corrispondenti per l\'importazione della cronologia si verificano con il tag dell\'asset. Cercheremo di trovare un utente corrispondente in base al nome dell\'utente che fornisci e ai criteri selezionati qui sotto. Se non si seleziona alcun criterio qui sotto, proverà semplicemente a corrispondere al formato del nome utente che hai configurato in <code>Admin &gt; Impostazioni Generali</code>.</p><p>I campi inclusi nel CSV devono corrispondere alle intestazioni: <strong>Asset Tag, Nome, Data di Checkout, Data di Checkin</strong>. Eventuali campi aggiuntivi verranno ignorati. </p><p>Data di Checkin: le date di check in vuote o future assegneranno gli elementi all\'utente associato. Esclusa la colonna Data di controllo creerà una data di check-in con la data di oggi.</p>
    ',
    'csv_import_match_f-l' => 'Prova ad abbinare gli utenti con il formato <strong>firstname.lastname</strong> (<code>jane.smith</code>)',
    'csv_import_match_initial_last' => 'Prova ad abbinare gli utenti con il formato <strong>primo cognome</strong> (<code>jsmith</code>)',
    'csv_import_match_first' => 'Prova ad abbinare gli utenti con il formato <strong>nome</strong> (<code>jane</code>)',
    'csv_import_match_email' => 'Prova a abbinare gli utenti con <strong>email</strong> come nome utente',
    'csv_import_match_username' => 'Prova ad abbinare gli utenti con il nome utente <strong></strong>',
    'error_messages' => 'Messaggi di errore:',
    'success_messages' => 'Messaggi di successo:',
    'alert_details' => 'Leggere sotto per maggiori dettagli.',
    'custom_export' => 'Esportazione Personalizzata',
    'mfg_warranty_lookup' => ':manufacturer Cerca Stato Garanzia',
    'user_department' => 'Dipartimento Utente',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/it-IT/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Informazioni sugli asset',
    'about_assets_text'            => 'Gli asset sono elementi tracciati con il numero di serie o il tag di asset. Tendono ad essere oggetti di valore più elevato dove identificare un elemento specifico.',
    'archived'  				=> 'Archiviato',
    'asset'  					=> 'Bene',
    'bulk_checkout'             => 'Ritiro Asset',
    'bulk_checkin'              => 'Check-in Bene',
    'checkin'  					=> 'Ingresso Asset',
    'checkout'  				=> 'Asset Checkout',
    'clone'  					=> 'Copia Asset',
    'deployable'  				=> 'Assegnabile',
    'deleted'  					=> 'Questo bene è stato eliminato.',
    'delete_confirm'            => 'Sei sicuro di voler eliminare questo bene?',
    'edit'  					=> 'Modifica Asset',
    'model_deleted'  			=> 'Questo modello di asset è stato eliminato. Devi ripristinare il modello prima di poter ripristinare il bene.',
    'model_invalid'             => 'Il modello di questo bene non è valido.',
    'model_invalid_fix'         => 'Il bene deve avere un modello valido prima di poterne fare l\'assegnazioni, check-in o controlli.',
    'requestable'               => 'Disponibile',
    'requested'				    => 'richiesto',
    'not_requestable'           => 'Non Richiedibili',
    'requestable_status_warning' => 'Non cambiare richiedibilità',
    'restore'  					=> 'Ripristina Asset',
    'pending'  					=> 'In attesa',
    'undeployable'  			=> 'Non Distribuilbile',
    'undeployable_tooltip'  	=> 'Questo bene ha una etichetta che lo rende non distribuibile, il check-out non può avvenire.',
    'view'  					=> 'Vedi Asset',
    'csv_error' => 'C\'è un errore nel file CSV:',
    'import_text' => '<p>Carica un CSV che contiene la cronologia degli asset. Gli asset e gli utenti DEVONO già esistere nel sistema, o saranno saltati. Le risorse corrispondenti per l\'importazione della cronologia si verificano con il tag dell\'asset. Cercheremo di trovare un utente corrispondente in base al nome dell\'utente che fornisci e ai criteri selezionati qui sotto. Se non si seleziona alcun criterio qui sotto, proverà semplicemente a corrispondere al formato del nome utente che hai configurato in <code>Admin &gt; Impostazioni Generali</code>.</p><p>I campi inclusi nel CSV devono corrispondere alle intestazioni: <strong>Asset Tag, Nome, Data di Checkout, Data di Checkin</strong>. Eventuali campi aggiuntivi verranno ignorati. </p><p>Data di Checkin: le date di check in vuote o future assegneranno gli elementi all\'utente associato. Esclusa la colonna Data di controllo creerà una data di check-in con la data di oggi.</p>
    ',
    'csv_import_match_f-l' => 'Prova ad abbinare gli utenti con il formato <strong>firstname.lastname</strong> (<code>jane.smith</code>)',
    'csv_import_match_initial_last' => 'Prova ad abbinare gli utenti con il formato <strong>primo cognome</strong> (<code>jsmith</code>)',
    'csv_import_match_first' => 'Prova ad abbinare gli utenti con il formato <strong>nome</strong> (<code>jane</code>)',
    'csv_import_match_email' => 'Prova a abbinare gli utenti con <strong>email</strong> come nome utente',
    'csv_import_match_username' => 'Prova ad abbinare gli utenti con il nome utente <strong></strong>',
    'error_messages' => 'Messaggi di errore:',
    'success_messages' => 'Messaggi di successo:',
    'alert_details' => 'Leggere sotto per maggiori dettagli.',
    'custom_export' => 'Esportazione Personalizzata',
    'mfg_warranty_lookup' => ':manufacturer Cerca Stato Garanzia',
    'user_department' => 'Dipartimento Utente',
];
